==> knative-model-6.0.0-sources.jar: io/fabric8/knative/messaging/v1/ChannelStatusFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import java.lang.Deprecated;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusBuilder;
import java.util.Iterator;
import java.util.List;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface ChannelStatusFluent<A extends ChannelStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public ChannelStatusFluent.AddressNested<A> withNewAddress();
  public ChannelStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public ChannelStatusFluent.AddressNested<A> editAddress();
  public ChannelStatusFluent.AddressNested<A> editOrNewAddress();
  public ChannelStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  
  /**
   * This method has been deprecated, please use method buildChannel instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getChannel();
  public KReference buildChannel();
  public A withChannel(KReference channel);
  public Boolean hasChannel();
  public A withNewChannel(String apiVersion,String kind,String name,String namespace);
  public ChannelStatusFluent.ChannelNested<A> withNewChannel();
  public ChannelStatusFluent.ChannelNested<A> withNewChannelLike(KReference item);
  public ChannelStatusFluent.ChannelNested<A> editChannel();
  public ChannelStatusFluent.ChannelNested<A> editOrNewChannel();
  public ChannelStatusFluent.ChannelNested<A> editOrNewChannelLike(KReference item);
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public ChannelStatusFluent.ConditionsNested<A> addNewCondition();
  public ChannelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public ChannelStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public ChannelStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public ChannelStatusFluent.ConditionsNested<A> editFirstCondition();
  public ChannelStatusFluent.ConditionsNested<A> editLastCondition();
  public ChannelStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDeadLetterChannel instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getDeadLetterChannel();
  public KReference buildDeadLetterChannel();
  public A withDeadLetterChannel(KReference deadLetterChannel);
  public Boolean hasDeadLetterChannel();
  public A withNewDeadLetterChannel(String apiVersion,String kind,String name,String namespace);
  public ChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannel();
  public ChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannelLike(KReference item);
  public ChannelStatusFluent.DeadLetterChannelNested<A> editDeadLetterChannel();
  public ChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannel();
  public ChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannelLike(KReference item);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public A addToSubscribers(Integer index,SubscriberStatus item);
  public A setToSubscribers(Integer index,SubscriberStatus item);
  public A addToSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... items);
  public A addAllToSubscribers(Collection<SubscriberStatus> items);
  public A removeFromSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... items);
  public A removeAllFromSubscribers(Collection<SubscriberStatus> items);
  public A removeMatchingFromSubscribers(Predicate<SubscriberStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubscribers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriberStatus> getSubscribers();
  public List<SubscriberStatus> buildSubscribers();
  public SubscriberStatus buildSubscriber(Integer index);
  public SubscriberStatus buildFirstSubscriber();
  public SubscriberStatus buildLastSubscriber();
  public SubscriberStatus buildMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public Boolean hasMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public A withSubscribers(List<SubscriberStatus> subscribers);
  public A withSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... subscribers);
  public Boolean hasSubscribers();
  public A addNewSubscriber(String message,Long observedGeneration,String ready,String uid);
  public ChannelStatusFluent.SubscribersNested<A> addNewSubscriber();
  public ChannelStatusFluent.SubscribersNested<A> addNewSubscriberLike(SubscriberStatus item);
  public ChannelStatusFluent.SubscribersNested<A> setNewSubscriberLike(Integer index,SubscriberStatus item);
  public ChannelStatusFluent.SubscribersNested<A> editSubscriber(Integer index);
  public ChannelStatusFluent.SubscribersNested<A> editFirstSubscriber();
  public ChannelStatusFluent.SubscribersNested<A> editLastSubscriber();
  public ChannelStatusFluent.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<ChannelStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ChannelNested<N> extends Nested<N>,KReferenceFluent<ChannelStatusFluent.ChannelNested<N>>{
    public N and();
    public N endChannel();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<ChannelStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface DeadLetterChannelNested<N> extends Nested<N>,KReferenceFluent<ChannelStatusFluent.DeadLetterChannelNested<N>>{
    public N and();
    public N endDeadLetterChannel();
    
  }
  public interface SubscribersNested<N> extends Nested<N>,SubscriberStatusFluent<ChannelStatusFluent.SubscribersNested<N>>{
    public N and();
    public N endSubscriber();
    
  }
  
}

==> knative-model-6.3.1-sources.jar: io/fabric8/knative/messaging/v1/ChannelStatusFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import java.lang.Deprecated;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusBuilder;
import java.util.Iterator;
import java.util.List;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface ChannelStatusFluent<A extends ChannelStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public ChannelStatusFluent.AddressNested<A> withNewAddress();
  public ChannelStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public ChannelStatusFluent.AddressNested<A> editAddress();
  public ChannelStatusFluent.AddressNested<A> editOrNewAddress();
  public ChannelStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  
  /**
   * This method has been deprecated, please use method buildChannel instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getChannel();
  public KReference buildChannel();
  public A withChannel(KReference channel);
  public Boolean hasChannel();
  public A withNewChannel(String apiVersion,String group,String kind,String name,String namespace);
  public ChannelStatusFluent.ChannelNested<A> withNewChannel();
  public ChannelStatusFluent.ChannelNested<A> withNewChannelLike(KReference item);
  public ChannelStatusFluent.ChannelNested<A> editChannel();
  public ChannelStatusFluent.ChannelNested<A> editOrNewChannel();
  public ChannelStatusFluent.ChannelNested<A> editOrNewChannelLike(KReference item);
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public ChannelStatusFluent.ConditionsNested<A> addNewCondition();
  public ChannelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public ChannelStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public ChannelStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public ChannelStatusFluent.ConditionsNested<A> editFirstCondition();
  public ChannelStatusFluent.ConditionsNested<A> editLastCondition();
  public ChannelStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDeadLetterChannel instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getDeadLetterChannel();
  public KReference buildDeadLetterChannel();
  public A withDeadLetterChannel(KReference deadLetterChannel);
  public Boolean hasDeadLetterChannel();
  public A withNewDeadLetterChannel(String apiVersion,String group,String kind,String name,String namespace);
  public ChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannel();
  public ChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannelLike(KReference item);
  public ChannelStatusFluent.DeadLetterChannelNested<A> editDeadLetterChannel();
  public ChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannel();
  public ChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannelLike(KReference item);
  public String getDeadLetterSinkUri();
  public A withDeadLetterSinkUri(String deadLetterSinkUri);
  public Boolean hasDeadLetterSinkUri();
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public A addToSubscribers(Integer index,SubscriberStatus item);
  public A setToSubscribers(Integer index,SubscriberStatus item);
  public A addToSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... items);
  public A addAllToSubscribers(Collection<SubscriberStatus> items);
  public A removeFromSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... items);
  public A removeAllFromSubscribers(Collection<SubscriberStatus> items);
  public A removeMatchingFromSubscribers(Predicate<SubscriberStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubscribers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriberStatus> getSubscribers();
  public List<SubscriberStatus> buildSubscribers();
  public SubscriberStatus buildSubscriber(Integer index);
  public SubscriberStatus buildFirstSubscriber();
  public SubscriberStatus buildLastSubscriber();
  public SubscriberStatus buildMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public Boolean hasMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public A withSubscribers(List<SubscriberStatus> subscribers);
  public A withSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... subscribers);
  public Boolean hasSubscribers();
  public A addNewSubscriber(String message,Long observedGeneration,String ready,String uid);
  public ChannelStatusFluent.SubscribersNested<A> addNewSubscriber();
  public ChannelStatusFluent.SubscribersNested<A> addNewSubscriberLike(SubscriberStatus item);
  public ChannelStatusFluent.SubscribersNested<A> setNewSubscriberLike(Integer index,SubscriberStatus item);
  public ChannelStatusFluent.SubscribersNested<A> editSubscriber(Integer index);
  public ChannelStatusFluent.SubscribersNested<A> editFirstSubscriber();
  public ChannelStatusFluent.SubscribersNested<A> editLastSubscriber();
  public ChannelStatusFluent.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<ChannelStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ChannelNested<N> extends Nested<N>,KReferenceFluent<ChannelStatusFluent.ChannelNested<N>>{
    public N and();
    public N endChannel();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<ChannelStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface DeadLetterChannelNested<N> extends Nested<N>,KReferenceFluent<ChannelStatusFluent.DeadLetterChannelNested<N>>{
    public N and();
    public N endDeadLetterChannel();
    
  }
  public interface SubscribersNested<N> extends Nested<N>,SubscriberStatusFluent<ChannelStatusFluent.SubscribersNested<N>>{
    public N and();
    public N endSubscriber();
    
  }
  
}
